// Modifiers.java - modifiers interface
// Rob Earhart
// $Id$
//
/***********************************************************
        Copyright 1997 by Carnegie Mellon University

                      All Rights Reserved

Permission to use, copy, modify, and distribute this software and its
documentation for any purpose and without fee is hereby granted,
provided that the above copyright notice appear in all copies and that
both that copyright notice and this permission notice appear in
supporting documentation, and that the name of CMU not be
used in advertising or publicity pertaining to distribution of the
software without specific, written prior permission.

CMU DISCLAIMS ALL WARRANTIES WITH REGARD TO THIS SOFTWARE, INCLUDING
ALL IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS, IN NO EVENT SHALL
CMU BE LIABLE FOR ANY SPECIAL, INDIRECT OR CONSEQUENTIAL DAMAGES OR
ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS,
WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION,
ARISING OUT OF OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS
SOFTWARE.
******************************************************************/

package acap;

import java.io.DataOutputStream;

/**
 * Encapsulates a set of modifiers to apply to a search.
 * @see acap.Conn
 */
public class Modifiers extends Sendable {
  Integer limit;
  String makecontext;
  Return[] returnlist;
  Sort[] sortlist;
  /**
   * Constructs a Modifiers object.
   * Any argument may be specified as <b>null</b> to signify
   * the lack of the corresponding modifier.
   * @param limit the maximum number of search results to return
   * @param makecontext the context to create out of this search
   * @param returnlist the list of attributes to return
   * @param sortlist the order in which returned entries should be sorted
   * @see acap.Return
   * @see acap.Sort
   */
  public Modifiers(Integer limit,
		   String makecontext,
		   Return[] returnlist,
		   Sort[] sortlist) {
    this.limit = limit;
    this.makecontext = makecontext;
    this.returnlist = returnlist;
    this.sortlist = sortlist;
  }
  void Send(DataOutputStream out)
    throws java.io.IOException {
      boolean first = true;
      if (limit != null) {
	out.writeBytes("Limit ");
	out.writeBytes(limit.toString());
	first = false;
      }
      if (makecontext != null) {
	if (! first) out.writeByte(' ');
	out.writeBytes("MakeContext ");
	SendString.Send(makecontext, out);
	first = false;
      }
      if (returnlist != null) {
	if (! first) out.writeByte(' ');
	out.writeBytes("Return (");
	for (int lupe = 0; lupe < returnlist.length; lupe++) {
	  returnlist[lupe].Send(out);
	  if (lupe < (returnlist.length - 1))
	    out.writeByte(' ');
	}
	out.writeByte(')');
	first = false;
      }
      if (sortlist != null) {
	if (! first) out.writeByte(' ');
	out.writeBytes("Sort (");
	for (int lupe = 0; lupe < sortlist.length; lupe++) {
	  sortlist[lupe].Send(out);
	  if (lupe < (sortlist.length - 1))
	    out.writeByte(' ');
	}
	out.writeByte(')');
      }
  }
}

