// NotifyHandler.java - notification handler
// Rob Earhart
// $Id$
//
/***********************************************************
        Copyright 1997 by Carnegie Mellon University

                      All Rights Reserved

Permission to use, copy, modify, and distribute this software and its
documentation for any purpose and without fee is hereby granted,
provided that the above copyright notice appear in all copies and that
both that copyright notice and this permission notice appear in
supporting documentation, and that the name of CMU not be
used in advertising or publicity pertaining to distribution of the
software without specific, written prior permission.

CMU DISCLAIMS ALL WARRANTIES WITH REGARD TO THIS SOFTWARE, INCLUDING
ALL IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS, IN NO EVENT SHALL
CMU BE LIABLE FOR ANY SPECIAL, INDIRECT OR CONSEQUENTIAL DAMAGES OR
ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS,
WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION,
ARISING OUT OF OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS
SOFTWARE.
******************************************************************/

package acap;

import java.util.Vector;

/**
 * NotifyHandler specifies an abstract interface to be used
 * for context notification.
 */
public abstract class NotifyHandler {
  /**
   * AddTo is called when an entry has been added to
   * a context.  The position indicates the position number that
   * the new entry has (first entry numbered 0, comma
   * darn it what drugs was John smoking when he made it 1?)
   * @param entry the entry that was added
   * @param position its position in the context
   * @param values the data requested in the NotifyContext command
   * @see acap.Conn
   */
  public abstract void AddTo(String entry,
			     int position,
			     Vector values);
  /**
   * Change is called when an entry changes its position in a
   * context, or has changed value.  The positions indicate
   * the entry's old and new positions in the context, and are 0-based.
   * @param entry the entry that was changed
   * @param oldposition its original position in the context
   * @param newposition its new position in the context
   * @param values the data requested in the NotifyContext command
   * @see acap.Conn */
  public abstract void Change(String entry,
			      int oldposition,
			      int newposition,
			      Vector values);
  /**
   * RemoveFrom is called when an entry has been removed from
   * a context.  The position indicates the position number that
   * the entry had (first entry numbered 0)
   * @param entry the entry that was added
   * @param position its position in the context
   * @see acap.Conn
   */
  public abstract void RemoveFrom(String entry,
				  int position);
  /**
   * Modtime informs the client that it has recieved all updates
   * to entries in the context which have modtime values less
   * than the supplied time.
   * @param time the modtime
   * @see acap.Conn
   */
  public abstract void ModTime(String time);
}

